==> owncloud-tasks_0.7.1.orig.tar.gz: tasks-0.7.1/l10n/fr.php <==
<?php
$TRANSLATIONS = array(
"Tasks" => "Tâches",
"Due yesterday" => "Pour hier",
"Due today" => "Pour aujourd'hui",
"Due tomorrow" => "Pour demain",
"Due on" => "Echéance",
"Started yesterday" => "Débutées hier",
"Starts today" => "Débute aujourd'hui",
"Starts tomorrow" => "Débute demain",
"Started on" => "Débuté le",
"Starts on" => "Débute le",
"[Remind me yesterday at ]HH:mm" => "[Rappel hier à ]HH:mm",
"[Remind me today at ]HH:mm" => "[Rappel aujourd'hui à ]HH:mm",
"[Remind me tomorrow at ]HH:mm" => "[Rappel demain à ]HH:mm",
"[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" => "[Rappel le ]MMM DD, YYYY,[ à ]HH:mm",
"Yesterday" => "Hier",
"Today" => "Aujourd'hui",
"Tomorrow" => "Demain",
"in %s" => "dans %s",
"%s ago" => "il y a %s",
"seconds" => "secondes",
"a minute" => "une minute",
"%d minutes" => "%d minutes",
"an hour" => "une heure",
"%d hours" => "%d heures",
"a day" => "un jour",
"%d days" => "%d jours",
"a month" => "un mois",
"%d months" => "%d mois",
"a year" => "un an",
"%d years" => "%d ans",
"Hours" => "Heures",
"Minutes" => "Minutes",
"week" => "semaine",
"weeks" => "semaines",
"day" => "jour",
"days" => "jours",
"hour" => "heure",
"hours" => "heures",
"minute" => "minute",
"minutes" => "minutes",
"second" => "deuxième",
"before beginning" => "avant le début",
"after beginning" => "après le début",
"before end" => "avant la fin",
"after end" => "après la fin",
"Comment" => "Commenter",
"Add a comment" => "Ajouter un commentaire",
"This will delete the Calendar \"%s\" and all of its entries." => "Ceci va supprimer le Calendrier \"%s\" et tout son contenu.",
"The name \"%s\" is already used." => "Le nom \"%s\" est déjà utilisé.",
"An empty name is not allowed." => "Un nom vide n'est pas autorisé.",
"Hidden" => "Caché",
"Visible" => "Visible",
"Automatic" => "Automatique",
"Sunday" => "Dimanche",
"Monday" => "Lundi",
"Tuesday" => "Mardi",
"Wednesday" => "Mercredi",
"Thursday" => "Jeudi",
"Friday" => "Vendredi",
"Saturday" => "Samedi",
"Add an important item in \"%s\"..." => "Ajouter un élément important dans \"%s\"...",
"Add an item due today in \"%s\"..." => "Ajouter un élément échéant aujourd'hui dans \"%s\"...",
"Add an item in \"%s\"..." => "Ajouter un élément dans \"%s\"...",
"Add a current item in \"%s\"..." => "Ajouter un élément courant dans \"%s\"...",
"_%n Completed Task_::_%n Completed Tasks_" => array("%n tâche terminée","%n tâches terminées"),
"Set due date" => "Spécifier la date d'échéance",
"%s %% completed" => "complétée à %s %%",
"priority %s: " => "priorité %s:",
"high" => "haute",
"medium" => "moyenne",
"low" => "basse",
"no priority assigned" => "Aucune priorité assignée",
"Remind me" => "Rappel",
"at the end" => "à la fin",
"at the beginning" => "au début",
"Set start date" => "Spécifier la date de début",
"Important" => "Important",
"Week" => "Cette semaine",
"All" => "Tout",
"Current" => "En ce moment",
"Completed" => "Terminé",
"rename" => "renommer",
"delete" => "supprimer",
"Add List..." => "Ajouter une liste...",
"New List" => "Nouvelle liste",
"Settings" => "Paramètres",
"Start of week" => "Début de semaine",
"Visibility of Smart Collections" => "Visibilité des collections Smart",
"Load remaining completed tasks." => "Charger le reste des tâches terminées.",
"(New category)" => "(Nouvelle catégorie)",
"Select categories..." => "Sélectionner des catégories...",
"Loading the task..." => "Chargement de la tâche…",
"Task not found!" => "Tâche non trouvée !"
);
$PLURAL_FORMS = "nplurals=2; plural=(n > 1);";

==> owncloud-tasks_0.8.1.orig.tar.gz: tasks-0.8.1/l10n/fr.php <==
<?php
$TRANSLATIONS = array(
"Tasks" => "Tâches",
"Tasks app is unavailable because the calendar is not installed" => "L'application \"Tâches\" n'est pas disponible car l'application \"Calendrier\" n'est pas installée.",
"Due yesterday" => "Pour hier",
"Due today" => "Pour aujourd'hui",
"Due tomorrow" => "Pour demain",
"Due on" => "Echéance",
"Started yesterday" => "Débutées hier",
"Starts today" => "Débute aujourd'hui",
"Starts tomorrow" => "Débute demain",
"Started on" => "Débuté le",
"Starts on" => "Débute le",
"[Remind me yesterday at ]HH:mm" => "[Rappel hier à ]HH:mm",
"[Remind me today at ]HH:mm" => "[Rappel aujourd'hui à ]HH:mm",
"[Remind me tomorrow at ]HH:mm" => "[Rappel demain à ]HH:mm",
"[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" => "[Rappel le ]MMM DD, YYYY,[ à ]HH:mm",
"Yesterday" => "Hier",
"Today" => "Aujourd'hui",
"Tomorrow" => "Demain",
"in %s" => "dans %s",
"%s ago" => "il y a %s",
"seconds" => "secondes",
"a minute" => "une minute",
"%d minutes" => "%d minutes",
"an hour" => "une heure",
"%d hours" => "%d heures",
"a day" => "un jour",
"%d days" => "%d jours",
"a month" => "un mois",
"%d months" => "%d mois",
"a year" => "un an",
"%d years" => "%d ans",
"Hours" => "Heures",
"Minutes" => "Minutes",
"week" => "semaine",
"weeks" => "semaines",
"day" => "jour",
"days" => "jours",
"hour" => "heure",
"hours" => "heures",
"minute" => "minute",
"minutes" => "minutes",
"second" => "seconde",
"before beginning" => "avant le début",
"after beginning" => "après le début",
"before end" => "avant la fin",
"after end" => "après la fin",
"Comment" => "Commenter",
"Add a comment" => "Ajouter un commentaire",
"This will delete the Calendar \"%s\" and all of its entries." => "Ceci va supprimer le Calendrier \"%s\" et tout son contenu.",
"The name \"%s\" is already used." => "Le nom \"%s\" est déjà utilisé.",
"An empty name is not allowed." => "Un nom vide n'est pas autorisé.",
"Hidden" => "Caché",
"Visible" => "Visible",
"Automatic" => "Automatique",
"Sunday" => "Dimanche",
"Monday" => "Lundi",
"Tuesday" => "Mardi",
"Wednesday" => "Mercredi",
"Thursday" => "Jeudi",
"Friday" => "Vendredi",
"Saturday" => "Samedi",
"Add an important item in \"%s\"..." => "Ajouter un élément important dans \"%s\"...",
"Add an item due today in \"%s\"..." => "Ajouter un élément échéant aujourd'hui dans \"%s\"...",
"Add an item in \"%s\"..." => "Ajouter un élément dans \"%s\"...",
"Add a current item in \"%s\"..." => "Ajouter un élément courant dans \"%s\"...",
"Add a subtask to \"%s\"..." => "Ajouter une sous-tâche à \"%s\"...",
"_%n Completed Task_::_%n Completed Tasks_" => array("%n tâche terminée","%n tâches terminées"),
"Set due date" => "Spécifier la date d'échéance",
"%s %% completed" => "complétée à %s %%",
"priority %s: " => "priorité %s :",
"high" => "haute",
"medium" => "moyenne",
"low" => "basse",
"no priority assigned" => "aucune priorité assignée",
"Remind me" => "Rappel",
"at the end" => "à la fin",
"at the beginning" => "au début",
"Set start date" => "Spécifier la date de début",
"Important" => "Important",
"Week" => "Cette semaine",
"All" => "Tout",
"Current" => "En ce moment",
"Completed" => "Terminé",
"rename" => "renommer",
"delete" => "suppression",
"Add List..." => "Ajouter une liste...",
"New List" => "Nouvelle liste",
"Settings" => "Paramètres",
"Start of week" => "Début de semaine",
"Visibility of Smart Collections" => "Visibilité des collections Smart",
"Load remaining completed tasks." => "Charger le reste des tâches terminées.",
"(New category)" => "(Nouvelle catégorie)",
"Select categories..." => "Sélectionner des catégories...",
"Loading the task..." => "Chargement de la tâche…",
"Task not found!" => "Tâche non trouvée !",
"add a subtask to" => "ajouter une sous-tâche à"
);
$PLURAL_FORMS = "nplurals=2; plural=(n > 1);";
